<?php
namespace App\Http\Controllers;

use App\Models\Checkout;
use App\Models\User;
use Illuminate\Http\Request;
use App\Models\Product;
use Illuminate\Support\Facades\Log;
class AdminController extends Controller
{
    // Método para exibir o dashboard
    public function dashboard()
    {
        // Recupera todos os pedidos, incluindo o nome do usuário com o join
        $checkouts = Checkout::join('users', 'checkouts.user_id', '=', 'users.id')
                             ->select('checkouts.*', 'users.name as user_name')
                             ->get();

        // Recupera todos os usuários para o select
        $products = Product::all();
        $users = User::all();

        return view('admin.dashboard', compact('checkouts', 'users','products'));
    }



    // Método para atualizar o status do pedido
    public function updateStatus(Request $request, $id)
    {
        $checkout = Checkout::findOrFail($id);

        // Validação condicional
        $request->validate([
            'status' => 'required|string',
            'tracking_code' => $request->status === 'postado_no_correios' ? 'required|string' : 'nullable',
        ]);

        // Atualiza o status
        $checkout->status = $request->status;

        // Adiciona o código dos Correios se aplicável
        if ($request->status === 'postado_no_correios') {
            $checkout->tracking_code = $request->tracking_code; // Salva na coluna tracking_code
        } else {
            $checkout->tracking_code = null; // Limpa o campo se o status não for postado
        }

        $checkout->save();

        return redirect()->back()->with('success', 'Status atualizado com sucesso!');
    }


public function updateOrderValue(Request $request, $id)
{
    Log::info('Iniciando a atualização do valor do pedido', ['pedido_id' => $id]);

    try {
        $checkout = Checkout::findOrFail($id);
        Log::info('Pedido encontrado', ['pedido' => $checkout]);

        // Validação do valor
        $validated = $request->validate([
            'total' => 'required|numeric|min:0',
        ]);
        Log::info('Validação bem-sucedida', ['dados_validados' => $validated]);

        // Atualiza o valor do pedido
        $checkout->total = $request->total;
        $checkout->save();

        Log::info('Valor do pedido atualizado com sucesso', ['novo_total' => $checkout->total]);

        return redirect()->back()->with('success', 'Valor do pedido atualizado com sucesso!');
    } catch (\Illuminate\Validation\ValidationException $e) {
        Log::error('Erro de validação', ['erros' => $e->errors()]);
        return redirect()->back()->withErrors($e->errors());
    } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $e) {
        Log::error('Pedido não encontrado', ['pedido_id' => $id]);
        return redirect()->back()->with('error', 'Pedido não encontrado!');
    } catch (\Exception $e) {
        Log::error('Erro inesperado ao atualizar o valor do pedido', [
            'pedido_id' => $id,
            'mensagem' => $e->getMessage(),
            'stack' => $e->getTraceAsString(),
        ]);
        return redirect()->back()->with('error', 'Ocorreu um erro ao atualizar o valor do pedido.');
    }
}



    // Método para atualizar o usuário do pedido
    public function updateUser(Request $request, $id)
    {
        $checkout = Checkout::findOrFail($id);
        $checkout->user_id = $request->input('user_id');
        $checkout->save();

        return redirect()->route('admin.dashboard')->with('success', 'Usuário do pedido alterado com sucesso!');
    }
    public function updateProducts(Request $request, $id)
{
    $checkout = Checkout::findOrFail($id);
    $checkout->products()->sync($request->input('product_id')); // Associar produtos ao checkout

    return redirect()->route('admin.dashboard')->with('success', 'Produtos atualizados com sucesso!');
}

}
