<?php

namespace App\Http\Controllers;

use App\Models\Product;
use Illuminate\Http\Request;

class ItensVendaController extends Controller
{
    // Construtor do controlador, sem middleware
    public function __construct()
    {
        // Nenhum middleware aqui
    }

    // Método para listar os produtos
    public function index()
    {
        $products = Product::all(); // Obtém todos os produtos do banco de dados
        return view('itens_venda.index', compact('products')); // Retorna a view com os produtos
    }

    // Método para editar um produto
    public function edit($id)
    {
        $product = Product::findOrFail($id);
        return view('itens_venda.edit_partial', compact('product'));
    }


    // Método para atualizar um produto
    public function update(Request $request, Product $product)
    {
        $product->name = $request->name;
        $product->description = $request->description;
        $product->price = $request->price;
        $product->category = $request->category;
        $product->fragrance = $request->fragrance;
        $product->burn_time = $request->burn_time;
        $product->weight = $request->weight;

        // Se a imagem for enviada, salva a nova imagem
        if ($request->hasFile('image')) {
            $product->image = $request->file('image')->store('images');
        }

        $product->save(); // Atualiza o produto no banco de dados

        return redirect()->route('itens_venda.index')->with('success', 'Produto atualizado com sucesso!');
    }

    // Método para desativar um produto
    public function deactivate(Product $product)
    {
        $product->is_active = false; // Marca o produto como inativo
        $product->save();

        return redirect()->route('itens_venda.index')->with('success', 'Produto desativado com sucesso!');
    }
}
