<?php

namespace App\Http\Controllers;

use App\Models\Pedido;
use App\Models\ItemPedido;
use App\Models\Cliente;
use App\Models\Massa;
use App\Models\Recheio;
use App\Models\Produto;
use Illuminate\Http\Request;

class PedidoController extends Controller
{
    // Lista todos os pedidos
    public function index()
    {
        $pedidos = Pedido::with('cliente')->get(); // Inclui informações do cliente
        return view('pedidos.index', compact('pedidos'));
    }

    // Exibe o formulário de criação


    // Salva um novo pedido
    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'pedido_id' => 'required|exists:pedidos,id',
            'tipo' => 'required|string|max:255',
            'descricao' => 'required|string|max:255',
            'preco' => 'required|numeric|min:0',
            'quantidade' => 'required|integer|min:1',
        ]);

        // Cria o item do pedido
        $item = ItemPedido::create($validatedData);

        // Atualiza o total do pedido
        $pedido = Pedido::find($request->pedido_id);
        $pedido->total += $item->preco * $item->quantidade;
        $pedido->save();

        return redirect()->route('pedidos.create')->with('success', 'Item adicionado com sucesso!');
    }



    // Exibe detalhes do pedido
    public function show(Pedido $pedido)
    {
        $pedido->load('itens', 'cliente'); // Inclui itens e cliente no pedido
        return view('pedidos.show', compact('pedido'));
    }

    // Exibe formulário de edição
    public function edit(Pedido $pedido)
    {
        $clientes = Cliente::all();
        $pedido->load('itens'); // Inclui os itens
        return view('pedidos.edit', compact('pedido', 'clientes'));
    }

    // Atualiza um pedido existente
    public function update(Request $request, Pedido $pedido)
    {
        $validated = $request->validate([
            'cliente_id' => 'required|exists:clientes,id',
            'data_pedido' => 'required|date',
            'previsao_entrega' => 'required|date',
            'preco_mao_obra' => 'required|numeric|min:0',
            'itens' => 'required|array',
            'itens.*.tipo' => 'required|string',
            'itens.*.descricao' => 'required|string',
            'itens.*.preco' => 'required|numeric|min:0',
            'itens.*.quantidade' => 'required|integer|min:1',
        ]);

        // Atualizar o pedido
        $pedido->update([
            'cliente_id' => $validated['cliente_id'],
            'data_pedido' => $validated['data_pedido'],
            'previsao_entrega' => $validated['previsao_entrega'],
            'preco_mao_obra' => $validated['preco_mao_obra'],
        ]);

        // Atualizar os itens
        $pedido->itens()->delete(); // Remove itens antigos
        $total = 0;
        foreach ($validated['itens'] as $item) {
            $subtotal = $item['preco'] * $item['quantidade'];
            $total += $subtotal;

            ItemPedido::create([
                'pedido_id' => $pedido->id,
                'tipo' => $item['tipo'],
                'descricao' => $item['descricao'],
                'preco' => $item['preco'],
                'quantidade' => $item['quantidade'],
                'subtotal' => $subtotal,
            ]);
        }

        // Atualizar o total do pedido
        $pedido->update(['total' => $total + $validated['preco_mao_obra']]);

        return redirect()->route('pedidos.index')->with('success', 'Pedido atualizado com sucesso!');
    }

    // Remove um pedido
    public function destroy(Pedido $pedido)
    {
        $pedido->delete();
        return redirect()->route('pedidos.index')->with('success', 'Pedido excluído com sucesso!');
    }

public function create()
{
    // Verifica se há um pedido em aberto
    $pedido = Pedido::where('status_pedido', 'aberto')->first();
    $massas = Massa::select('id', 'descricao', 'valor')->get();
    $recheios = Recheio::select('id', 'sabor', 'valor')->get();
    $produtos = Produto::select('id', 'nome', 'valor')->get();
    $clientes = Cliente::all();
    // Se não houver, cria um novo pedido
    if (!$pedido) {
        $pedido = Pedido::create([
            'cliente_id' => 1, // Cliente padrão
            'total' => 0.0,
            'status_pedido' => 'aberto',
        ]);
    }

    // Carrega os itens do pedido
    $itens = $pedido->itens;

    // Retorna para a view com os dados do pedido e itens
    $pedidoAberto = Pedido::where('status_pedido', 'aberto')->with('itens')->first();
return view('pedidos.create', compact('pedidoAberto', 'clientes', 'massas', 'recheios', 'produtos'));

}
public function storeItens(Request $request)
{
    $itens = $request->input('itens'); // Recebe os itens do pedido

    // Processa os itens e salva no banco de dados
    foreach ($itens as $item) {
        // Salve cada item no banco
        ItemPedido::create([
            'pedido_id' => $pedidoId, // O ID do pedido
            'tipo' => $item['tipo'],
            'descricao' => $item['descricao'],
            'preco' => $item['preco'],
            'quantidade' => $item['quantidade'],
            'total' => $item['total']
        ]);
    }

    return response()->json(['success' => true]);
}
public function additens (Request $request){
    $validatedData = $request->validate([
        'pedido_id' => 'required|exists:pedidos,id',
        'tipo' => 'required|string|max:255',
        'descricao' => 'required|string|max:255',
        'preco' => 'required|numeric|min:0',
        'quantidade' => 'required|integer|min:1',
    ]);

    // Cria o item do pedido
    $item = ItemPedido::create($validatedData);

    // Atualiza o total do pedido
    $pedido = Pedido::find($request->pedido_id);
    $pedido->total += $item->preco * $item->quantidade;
    $pedido->save();

    return redirect()->route('pedidos.create')->with('success', 'Item adicionado com sucesso!');
}
}
