<?php

namespace App\Http\Controllers;

use App\Models\Product;
use Illuminate\Http\Request;
namespace App\Http\Controllers;
use App\Models\CartItem;
use Illuminate\Http\Request;
use App\Models\Product;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;
class ProductController extends Controller
{
    public function create()
    { $userId = Auth::id();
        $cartItemCounts = CartItem::where('user_id', $userId)
        ->where('status', 'in_cart')
        ->sum('quantity');
        return view('products.create',compact('cartItemCounts'));
    }
    public function index()
{
    $query = request()->input('query');

    $products = Product::query()
        ->when($query, function($q) use ($query) {
            $q->where('name', 'like', '%' . $query . '%');
        })
        ->get(); // Executa a consulta e retorna os produtos filtrados

    $userId = Auth::id();
    return view('products.index', compact('products', 'userId'));
}



public function store(Request $request)
{
    // Validação dos dados recebidos
    $validated = $request->validate([
        'name' => 'required|string|max:255',
        'description' => 'required|string',
        'price' => 'required|numeric|min:0',
        'category' => 'required|string|max:255',
        'fragrance' => 'required|string|max:255',
        'burn_time' => 'required|string|max:255',
        'weight' => 'required|string|max:255',
        'images.*' => 'image|mimes:jpeg,png,jpg,gif|max:2048', // Permitir JPEG, PNG, JPG, GIF
        'main_image' => 'nullable|string', // Nome da imagem principal
    ]);

    $images = [];

    try {
        // Upload das imagens
        if ($request->hasFile('images')) {
            foreach ($request->file('images') as $index => $file) {
                try {
                    // Salvando a imagem no diretório public/img
                    $filename = time() . '_' . $index . '.' . $file->getClientOriginalExtension();
                    $path = public_path('img');
                    $file->move($path, $filename);

                    // Adicionando o caminho ao array de imagens
                    $images[] = 'img/' . $filename;

                    // Log de sucesso no upload de cada imagem
                    Log::info("Imagem {$filename} salva com sucesso.");
                } catch (\Exception $e) {
                    // Log de erro ao salvar uma imagem específica
                    Log::error("Erro ao salvar a imagem {$index}: " . $e->getMessage());
                    throw $e; // Relançar exceção para tratamento geral
                }
            }
        }

        // Criando o produto no banco de dados
        $product = Product::create([
            'name' => $validated['name'],
            'description' => $validated['description'],
            'price' => $validated['price'],
            'image' => $images[0] ?? null, // Define a primeira imagem como imagem principal, se nenhuma for informada
            'category' => $validated['category'],
            'fragrance' => $validated['fragrance'],
            'burn_time' => $validated['burn_time'],
            'weight' => $validated['weight'],
            'images' => json_encode($images), // Salva todas as imagens como JSON
            'main_image' => $validated['main_image'] ?? ($images[0] ?? null), // Define a imagem principal
        ]);

        // Log de sucesso na criação do produto
        Log::info("Produto {$product->id_product} cadastrado com sucesso.");
        return redirect()->back()->with('success', 'Produto cadastrado com sucesso!');

    } catch (\Exception $e) {
        // Log de erro geral
        Log::error("Erro ao cadastrar produto: " . $e->getMessage());
        return redirect()->back()->withErrors('Erro ao cadastrar produto. Verifique os logs para mais detalhes.');
    }
}




    public function update(Request $request, Product $product)
    {
        // Validar e atualizar o produto
        $validatedData = $request->validate([
            'name' => 'required|string|max:255',
            'description' => 'required|string|max:1000',
            'price' => 'required|numeric',
            'image' => 'nullable|image|max:1024',
        ]);

        $product->update($validatedData);

        // Se uma nova imagem foi enviada, faça o upload
        if ($request->hasFile('image')) {
            $imagePath = $request->file('image')->store('public/products');
            $product->image = $imagePath;
            $product->save();
        }

        return redirect()->route('products.index')->with('success', 'Produto atualizado com sucesso!');
    }
    public function promocao()
    {
        // Obter todos os produtos
        $products = Product::all();
        return view('promocao', compact('products'));
    }

    public function atualizarPromocao(Request $request)
    {
        try {
            // Busca o produto pelo ID
            $product = Product::findOrFail($request->id_product);

            // Atualiza os valores da promoção
            $product->is_promotion = $request->is_promotion; // 0 ou 1
            $product->discount_percentage = $request->is_promotion ? $request->discount_percentage : null;

            // Salva as mudanças no banco
            $product->save();

            return redirect()->back()->with('success', 'Promoção atualizada com sucesso.');
        } catch (\Exception $e) {
            return redirect()->back()->with('error', 'Erro ao atualizar promoção: ' . $e->getMessage());
        }
    }

    public function promocoes()
{
    // Buscar produtos em promoção
    $products = Product::where('is_promotion', 1)->get();

    return view('promocoes', compact('products'));
}
public function deactivate($id)
{
    // Encontrar o produto pelo ID
    $product = Product::findOrFail($id);

    // Alterar o status do produto para desativado
    $product->is_active = 0;
    $product->save();

    // Redirecionar com mensagem de sucesso
    return redirect()->route('promocoes')->with('success', 'Produto desativado com sucesso!');
}

}
