@extends('layouts.main')

@section('content')
    <div class="container">
        <h1>Cadastrar Produto</h1>
        <div class="container-cad-prod">
            <form action="{{ route('products.store') }}" method="POST" enctype="multipart/form-data">
                @csrf
                <div class="aling-itens">
                    <div class="form-group">
                        <label for="name">Nome</label>
                        <input type="text" name="name" id="name" class="form-control" required>
                    </div>

                    <div class="form-group">
                        <label for="description">Descrição</label>
                        <textarea name="description" id="description" class="form-control" required></textarea>
                    </div>
                </div>
                <div class="aling-itens">
                    <div class="form-group">
                        <label for="price">Preço</label>
                        <input type="text" name="price" id="price" class="form-control" required>
                    </div>
                    <div class="form-group">
                        <label for="category">Categoria</label>
                        <input type="text" name="category" id="category" class="form-control" required>
                    </div>

                    <div class="form-group">
                        <label for="fragrance">Fragrância</label>
                        <select name="fragrance" id="fragrance" class="form-control" required>
                            <option value="" disabled selected>Selecione uma fragrância</option>
                            <option value="Lavanda">Lavanda</option>
                            <option value="Baunilha">Baunilha</option>
                            <option value="Jasmim">Jasmim</option>
                            <option value="Rosa">Rosa</option>
                            <option value="Sândalo">Sândalo</option>
                            <option value="Outra">Outra (especifique abaixo)</option>
                        </select>
                    </div>
                    <div class="form-group" id="custom-fragrance-group" style="display: none;">
                        <label for="custom-fragrance">Fragrância Personalizada</label>
                        <input type="text" name="custom_fragrance" id="custom-fragrance" class="form-control">
                    </div>

                </div>
                <div class="form-group">
                    <label for="images">Imagens do Produto</label>
                    <input type="file" name="images[]" id="images" class="form-control" multiple>

                    <label for="main_image">Imagem Principal</label>
                    <select name="main_image" id="main_image" class="form-control" required>
                        <option value="" disabled selected>Selecione a imagem principal</option>
                    </select>
                </div>
                <div id="preview-container" style="display: flex; flex-wrap: wrap;"></div>

                <div class="aling-itens">
                    <div class="form-group">
                        <input type="checkbox" name="is_promotion" id="is_promotion" value="1">
                        <label for="is_promotion">Está em promoção?</label>
                        <input type="text" class="form-control mt-2" id="discount_percentage" name="discount_percentage"
                            placeholder="Desconto (%) (opcional)">
                    </div>

                    <div class="form-group">
                        <label for="burn_time">Tempo de Queima</label>
                        <input type="text" name="burn_time" id="burn_time" class="form-control" required>
                    </div>

                    <div class="form-group">
                        <label for="weight">Peso</label>
                        <input type="text" name="weight" id="weight" class="form-control" required>
                    </div>
                </div>
                <button type="submit" class="btn btn-primary mt-3">Salvar</button>
            </form>
        </div>
    </div>

    <script>
        document.getElementById('fragrance').addEventListener('change', function() {
            const customFragranceGroup = document.getElementById('custom-fragrance-group');
            if (this.value === 'Outra') {
                customFragranceGroup.style.display = 'block';
            } else {
                customFragranceGroup.style.display = 'none';
            }
        });

        // Máscara para o campo de preço
        document.getElementById('price').addEventListener('input', function() {
            let value = this.value.replace(/\D/g, '');
            value = (value / 100).toFixed(2);
            this.value = value.replace('.', ',').replace(/\B(?=(\d{3})+(?!\d))/g, '.');
        });

        // Máscara para o campo de tempo de queima no formato HH:mm
        document.getElementById('burn_time').addEventListener('input', function() {
            this.value = this.value.replace(/^(\d{2})(\d{2})$/, '$1:$2').substr(0, 5);
        });

        // Máscara para o campo de porcentagem
        document.getElementById('discount_percentage').addEventListener('input', function() {
            let value = this.value.replace(/\D/g, '');
            this.value = value > 100 ? '100%' : value + '%';
        });

        // Função para exibir preview da imagem principal
        document.getElementById('images').addEventListener('change', function() {
            const fileInput = this;
            const mainImageSelect = document.getElementById('main_image');
            const previewContainer = document.getElementById('preview-container');

            // Limpa o select e a pré-visualização de imagens
            mainImageSelect.innerHTML = '<option value="" disabled selected>Selecione a imagem principal</option>';
            previewContainer.innerHTML = '';

            // Adiciona as opções ao select e gera pré-visualizações
            Array.from(fileInput.files).forEach((file, index) => {
                const option = document.createElement('option');
                option.value = file.name;
                option.textContent = file.name;
                mainImageSelect.appendChild(option);

                // Criar preview das imagens
                const reader = new FileReader();
                reader.onload = function(e) {
                    const img = document.createElement('img');
                    img.src = e.target.result;
                    img.alt = file.name;
                    img.style.width = '100px';
                    img.style.height = '100px';
                    img.style.margin = '10px';
                    img.style.cursor = 'pointer';
                    img.style.border = '2px solid transparent';

                    // Clique na imagem para atualizar o select
                    img.addEventListener('click', function() {
                        mainImageSelect.value = file.name; // Atualiza o select
                        highlightImage(file.name); // Destaca a imagem
                    });

                    previewContainer.appendChild(img);
                };
                reader.readAsDataURL(file);
            });
        });

        // Evento para alterar destaque quando o select muda
        document.getElementById('main_image').addEventListener('change', function() {
            highlightImage(this.value); // Destaca a imagem correspondente ao valor do select
        });

        // Função para destacar a imagem selecionada
        function highlightImage(selectedFileName) {
            const allImages = document.querySelectorAll('#preview-container img');
            allImages.forEach(image => {
                if (image.alt === selectedFileName) {
                    image.style.border = '2px solid #007bff';
                    image.style.borderRadius = '8px';
                } else {
                    image.style.border = '2px solid transparent';
                }
            });
        }


        // Atualiza o destaque da imagem selecionada
        document.getElementById('main_image').addEventListener('change', function() {
            const selectedFile = this.value;
            const previewContainer = document.getElementById('image-preview');
            const images = previewContainer.querySelectorAll('img');

            images.forEach((img) => {
                if (img.dataset.filename === selectedFile) {
                    img.style.border = '2px solid #007bff';
                    img.style.borderRadius = '25px'; // Destaque da imagem selecionada
                } else {
                    img.style.border = 'none'; // Remove o destaque das demais
                }
            });
        });
        $(document).ready(function() {
            $('#burn_time').timepicker({
                showMeridian: false, // Formato 24 horas
                minuteStep: 1,
                secondStep: 1, // Para habilitar segundos
                defaultTime: false // Não preenche automaticamente
            });
        });
    </script>
@endsection
