@extends('layouts.main')

@section('content')
    <div class="container">
        <h1>Carrinho de Compras</h1>

        @if (isset($carrinho) && $carrinho->isNotEmpty())
            <div class="table-responsive">
                <div class="order-info">
                    <h4>Código do Pedido: {{ $carrinho->first()->order_code ?? 'Sem código de pedido' }}</h4>
                </div>

                <table class="table">
                    <thead>
                        <tr>
                            <th>Produto</th>
                            <th>Preço Unitário</th>
                            <th>Quantidade</th>
                            <th>Subtotal</th>
                            <th>Usuário</th>
                            <th>Açao</th>
                        </tr>
                    </thead>
                    <tbody>
                        @php
                            $totalCarrinho = 0; // Inicializa o total do carrinho
                        @endphp

                        @foreach ($carrinho as $item)
                            @php
                                // Calcula o preço final considerando a promoção
                                $finalPrice =
                                    $item->is_promotion && $item->discount_percentage > 0
                                        ? $item->price * (1 - $item->discount_percentage / 100)
                                        : $item->price;

                                $subtotal = $finalPrice * $item->quantity; // Calcula o subtotal do produto
                                $totalCarrinho += $subtotal; // Acumula o total do carrinho
                            @endphp
                            <tr>
                                <td>{{ $item->name }}</td>
                                <td>
                                    R$ {{ number_format($finalPrice, 2, ',', '.') }}
                                    @if ($item->is_promotion && $item->discount_percentage > 0)
                                        <small class="text-success">(Promoção: -{{ $item->discount_percentage }}%)</small>
                                    @endif
                                </td>
                                <td>{{ $item->quantity }}</td>
                                <td>R$ {{ number_format($subtotal, 2, ',', '.') }}</td> <!-- Subtotal -->
                                <td>{{ $item->user_name }}</td>
                                <td>
                                    <!-- Botão de Remover -->
                                    <form action="{{ route('cart.remove', $item->id) }}" method="POST"
                                        onsubmit="return confirm('Tem certeza que deseja remover este item do carrinho?');">
                                        @csrf
                                        @method('DELETE') <!-- Isso simula o método DELETE -->
                                        <button type="submit" class="btn btn-danger btn-sm">Remover</button>
                                    </form>
                                </td>
                            </tr>
                        @endforeach
                    </tbody>



                </table>

                <!-- Exibir o total do pedido -->
                <div class="mt-3">
                    <h4>Total do Carrinho</h4>
                    <p class="card-text-valor">
                        R$ {{ number_format($totalCarrinho, 2, ',', '.') }}
                    </p>
                </div>



                <!-- Exibir o formulário apenas na rota 'cart.checkout' -->
                @if (Route::currentRouteName() === 'cart.checkout')
                    <form action="{{ route('cart.checkout') }}" method="POST">
                        @csrf
                        <div class="mt-3">
                            <h4>Forma de Pagamento</h4>
                            <div>
                                <label for="payment_method">Escolha uma forma de pagamento:</label>
                                <select name="payment_method" id="payment_method" class="form-control">
                                    <option value="bank_account">Conta Bancária</option>
                                    <option value="pix">Pix</option>
                                </select>
                            </div>

                            <!-- Dados da conta bancária -->
                            <div id="bank_account_details" class="mt-3" style="display:none;">
                                <h5>Dados da Conta Bancária</h5>
                                <input type="text" name="bank_account_number" class="form-control"
                                    placeholder="Número da Conta" />
                                <input type="text" name="bank_account_agency" class="form-control mt-2"
                                    placeholder="Agência" />
                                <input type="text" name="bank_account_owner" class="form-control mt-2"
                                    placeholder="Titular da Conta" />
                            </div>

                            <!-- Dados do Pix -->
                            <div id="pix_details" class="mt-3" style="display:none;">
                                <h5>Chave Pix</h5>
                                <input type="text" name="pix_key" class="form-control" placeholder="Chave Pix" />
                            </div>

                            <button type="submit" class="btn btn-success mt-3">Finalizar Pedido</button>
                        </div>
                    </form>
                @else
                    <a href="{{ route('cart.checkout', ['order_code' => $carrinho->first()->order_code]) }}"
                        class="btn btn-primary mt-3">Ir para Finalizar Pedido</a>
                @endif
            @else
                <p>Seu carinho esta vazio <a href="{{ route('products.index') }}">Clique abrir produtos</p>
        @endif

    </div>

    <script>
        document.addEventListener('DOMContentLoaded', function() {
            document.getElementById('payment_method').addEventListener('change', function() {
                var method = this.value;
                if (method === 'bank_account') {
                    document.getElementById('bank_account_details').style.display = 'block';
                    document.getElementById('pix_details').style.display = 'none';
                } else if (method === 'pix') {
                    document.getElementById('pix_details').style.display = 'block';
                    document.getElementById('bank_account_details').style.display = 'none';
                }
            });
        });
    </script>
@endsection
