@extends('layouts.main')

@section('content')
    <div class="container">
        <h1 class="title-pag">Itens de Venda</h1>

        @if (session('success'))
            <div class="alert alert-success">
                {{ session('success') }}
            </div>
        @endif

        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>#</th>
                    <th>Imagem</th>
                    <th>Nome</th>
                    <th>Descrição</th>
                    <th>Preço</th>
                    @if (auth()->user() && auth()->user()->is_admin)
                        <th>Ações</th>
                    @endif
                </tr>
            </thead>
            <tbody>
                @foreach ($products as $product)
                    <tr>
                        <td>{{ $product->id_product }}</td>
                        <!-- Imagem com evento de clique -->
                        <td>
                            <img class="img-prod-list" src="{{ $product->image }}" alt="{{ $product->name }}"
                                onclick="showImageModal('{{ $product->image }}')">
                        </td>
                        <td>{{ $product->name }}</td>
                        <td>{{ $product->description }}</td>
                        <td>R$ {{ number_format($product->price, 2, ',', '.') }}</td>

                        @if (auth()->user() && auth()->user()->is_admin)
                            <td>
                                <!-- Editar Produto -->
                                <button class="btn btn-warning btn-sm"
                                    onclick="openEditModal('{{ route('itens_venda.edit', $product->id_product) }}')">
                                    Editar
                                </button>

                                <!-- Desativar Produto -->
                                <form action="{{ route('itens_venda.deactivate', $product->id_product) }}" method="POST"
                                    style="display:inline;">
                                    @csrf
                                    @method('PUT')
                                    <button type="submit" class="btn btn-danger btn-sm">Desativar</button>
                                </form>
                            </td>
                        @endif
                    </tr>
                @endforeach
            </tbody>
        </table>
        <script>
            function showImageModal(imageSrc) {
                // Atualiza o src da imagem no modal
                const modalImage = document.getElementById('modalImage');
                modalImage.src = imageSrc;

                // Exibe o modal
                const modal = document.getElementById('imageModal');
                modal.style.display = 'block';
            }

            function closeImageModal() {
                // Esconde o modal
                const modal = document.getElementById('imageModal');
                modal.style.display = 'none';
            }
        </script>
        <script>
            function openEditModal(url) {
                // Faz a requisição para carregar o formulário de edição
                fetch(url)
                    .then(response => {
                        if (!response.ok) {
                            throw new Error('Erro ao carregar o formulário.');
                        }
                        return response.text();
                    })
                    .then(html => {
                        // Insere o conteúdo do formulário na modal
                        document.getElementById('editFormContainer').innerHTML = html;
                        // Exibe a modal
                        const modal = document.getElementById('editModal');
                        modal.style.display = 'block';
                    })
                    .catch(error => {
                        console.error(error);
                        alert('Não foi possível carregar o formulário de edição.');
                    });
            }

            function closeEditModal() {
                // Esconde a modal
                const modal = document.getElementById('editModal');
                modal.style.display = 'none';
                // Limpa o conteúdo do formulário
                document.getElementById('editFormContainer').innerHTML = '';
            }
        </script>

        <!-- Modal para exibir a imagem -->
        <div id="imageModal" class="modal" tabindex="-1" style="display: none;">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title">Visualização da Imagem</h5>
                        <button type="button" class="btn-close" onclick="closeImageModal()"></button>
                    </div>
                    <div class="modal-body text-center">
                        <img id="modalImage" src="#" alt="Imagem do Produto" style="max-width: 100%; height: auto;">
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" onclick="closeImageModal()">Fechar</button>
                    </div>
                </div>
            </div>
        </div>
        <!-- Modal para Editar Produto -->
        <div id="editModal" class="modal" tabindex="-1" style="display: none;">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title">Editar Produto</h5>
                        <button type="button" class="btn-close" onclick="closeEditModal()"></button>
                    </div>
                    <div class="modal-body">
                        <!-- O formulário será carregado aqui dinamicamente -->
                        <div id="editFormContainer"></div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" onclick="closeEditModal()">Fechar</button>
                    </div>
                </div>
            </div>
        </div>

    </div>
@endsection
