@extends('layouts.main')

@section('content')
    <div class="container">
        <div class="container-produto-creat">
            <h1>Criar Pedido</h1>
            @if (session('success'))
                <div class="alert alert-success">
                    Pedido criado com sucesso. Número do Pedido: {{ session('success') }}
                </div>
            @endif

            @if ($pedidoAberto)
                <div class="alert alert-warning">
                    Existe um pedido em aberto. Número do Pedido: {{ $pedidoAberto->id }}.
                </div>
            @endif

            <!-- Formulário para salvar o pedido -->

            <h3>Itens do Pedido</h3>
            <form action="{{ route('pedidos.additens') }}" method="POST">

                <div class="row">
                    <div class="col-md-2">
                        <label for="pedido_id" class="form-label">Pedido</label>
                        <input type="number" class="form-control pedido" name="pedido_id" value="{{ $pedidoAberto->id }}"
                            required>
                    </div>
                    <div class="col-md-2">
                        <label for="tipo" class="form-label">Tipo</label>
                        <select class="form-control tipo" name="itens[0][tipo]" onchange="atualizarCampos(this)" required>
                            <option value="">Selecione</option>
                            <option value="massa">Massa</option>
                            <option value="recheio">Recheio</option>
                            <option value="produto">Produto</option>
                        </select>
                    </div>
                    <div class="col-md-4">
                        <label for="descricao" class="form-label">Descrição</label>
                        <select class="form-control descricao" name="itens[0][descricao]" required>
                            <!-- As opções serão carregadas dinamicamente -->
                        </select>
                    </div>
                    <div class="col-md-2">
                        <label for="preco" class="form-label">Preço</label>
                        <input type="number" step="0.01" class="form-control preco" name="itens[0][preco]" readonly
                            required>
                    </div>
                    <div class="col-md-2">
                        <label for="quantidade" class="form-label">Quantidade</label>
                        <input type="number" class="form-control quantidade" name="itens[0][quantidade]" value="1"
                            required>
                    </div>
                </div>
                <br>
                <button type="button" id="add-item" class="btn btn-secondary">Adicionar Item</button>
                <!-- Tabela de Itens -->
                <hr>

                <!-- Botão para adicionar novo item -->

            </form>
            <table id="tabela-itens" class="table">
                <thead>
                    <tr>
                        <th>Tipo</th>
                        <th>Descrição</th>
                        <th>Preço</th>
                        <th>Quantidade</th>
                        <th>Total</th>
                        <th>Ação</th>
                    </tr>
                </thead>
                <tbody id="itens-pedido"></tbody>
            </table>
            <hr>
            <form action="{{ route('pedidos.store') }}" method="POST">
                @csrf

                <div class="row">
                    <div class="col-md-4">
                        <label for="cliente_id" class="form-label">Cliente</label>
                        <select name="cliente_id" id="cliente_id" class="form-control" required>
                            <option value="">Selecione um cliente</option>
                            @foreach ($clientes as $cliente)
                                <option value="{{ $cliente->id_cliente }}"
                                    {{ $pedidoAberto && $pedidoAberto->cliente_id == $cliente->id_cliente ? 'selected' : '' }}>
                                    {{ $cliente->nome_cliente }}
                                </option>
                            @endforeach
                        </select>
                    </div>

                    <div class="col-md-4">
                        <label for="data_pedido" class="form-label">Data do Pedido</label>
                        <input type="date" class="form-control" id="data_pedido" name="data_pedido"
                            value="{{ $pedidoAberto ? $pedidoAberto->data_pedido : '' }}" required>
                    </div>

                    <div class="col-md-4">
                        <label for="previsao_entrega" class="form-label">Previsão de Entrega</label>
                        <input type="date" class="form-control" id="previsao_entrega" name="previsao_entrega"
                            value="{{ $pedidoAberto ? $pedidoAberto->previsao_entrega : '' }}" required>
                    </div>
                </div>

                <div class="row mt-3">
                    <div class="col-md-6">
                        <label for="preco_mao_obra" class="form-label">Preço da Mão de Obra</label>
                        <input type="number" step="0.01" class="form-control" id="preco_mao_obra" name="preco_mao_obra"
                            required>
                    </div>
                    <div class="col-md-6">
                        <label for="total" class="form-label">Total</label>
                        <input type="number" step="0.01" class="form-control" id="total" name="total" readonly>
                    </div>
                </div>

                <button type="submit" class="btn btn-primary mt-3">Salvar Pedido</button>
            </form>
        </div>
    </div>
    <script>
        const massas = @json($massas); // Dados de massas
        const recheios = @json($recheios); // Dados de recheios
        const produtos = @json($produtos); // Dados de produtos

        // Função para atualizar as opções de descrição e preço com base no tipo selecionado
        function atualizarCampos(selectTipo) {
            const tipo = selectTipo.value;
            const row = selectTipo.closest('.row');
            const descricaoSelect = row.querySelector('.descricao');
            const precoInput = row.querySelector('.preco');

            descricaoSelect.innerHTML = ''; // Limpa as opções anteriores

            let dados;
            if (tipo === 'massa') dados = massas;
            else if (tipo === 'recheio') dados = recheios;
            else if (tipo === 'produto') dados = produtos;

            if (dados) {
                dados.forEach(item => {
                    const option = document.createElement('option');
                    option.value = item.id;
                    option.textContent = item.descricao || item.sabor || item.nome;
                    option.setAttribute('data-preco', item.valor);
                    descricaoSelect.appendChild(option);
                });

                // Atualiza o preço com base na primeira opção
                precoInput.value = descricaoSelect.options[0]?.getAttribute('data-preco') || '';
            } else {
                precoInput.value = '';
            }
        }


        // Adicionar novo item à tabela
        document.getElementById('add-item').addEventListener('click', function() {
            let tabela = document.querySelector('#tabela-itens tbody');
            let row = tabela.insertRow();

            row.innerHTML = `
    <td>
        <select class="form-control tipo" name="itens[][tipo]" onchange="atualizarCampos(this)" required>
            <option value="">Selecione</option>
            <option value="massa">Massa</option>
            <option value="recheio">Recheio</option>
            <option value="produto">Produto</option>
        </select>
    </td>
    <td>
        <select class="form-control descricao" name="itens[][descricao]" required></select>
    </td>
    <td>
        <input type="number" class="form-control preco" name="itens[][preco]" step="0.01" readonly>
    </td>
    <td>
        <input type="number" class="form-control quantidade" name="itens[][quantidade]" value="1" required>
    </td>
    <td>
        <input type="number" class="form-control total-item" name="itens[][total]" readonly>
    </td>
    <td>
        <button type="button" class="btn btn-danger btn-sm" onclick="removerItem(this)">Remover</button>
    </td>
`;

        });

        // Função para remover um item
        function removerItem(btn) {
            btn.closest('tr').remove();
            calcularTotal();
        }

        // Função para calcular o total geral do pedido
        function calcularTotal() {
            let total = 0;
            document.querySelectorAll('#tabela-itens tbody tr').forEach(row => {
                const preco = parseFloat(row.querySelector('.preco').value) || 0;
                const quantidade = parseInt(row.querySelector('.quantidade').value) || 1;
                const totalItem = preco * quantidade;

                row.querySelector('.total-item').value = totalItem.toFixed(2);
                total += totalItem;
            });

            const maoDeObra = parseFloat(document.getElementById('preco_mao_obra').value) || 0;
            total += maoDeObra;

            document.getElementById('total').value = total.toFixed(2);
        }

        // Atualiza o total ao alterar preço ou quantidade
        document.addEventListener('input', function(event) {
            if (event.target.closest('#tabela-itens')) {
                calcularTotal();
            }
        });

        // Salvar itens no banco (envio do formulário)
        document.getElementById('salvar-itens').addEventListener('click', function() {
            const form = document.getElementById('form-itens-pedido');
            const formData = new FormData(form);

            fetch("{{ route('pedidos.storeItens') }}", { // Defina a rota para salvar os itens
                    method: 'POST',
                    body: formData,
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        alert('Itens salvos com sucesso!');
                    } else {
                        alert('Erro ao salvar os itens: ' + data.error);
                    }
                })
                .catch(error => {
                    console.error('Erro:', error);
                    alert('Erro ao processar o pedido.');
                });
        });
    </script>
@endsection
